@@ -29,8 +29,7 @@ fRegress <- function(yfdPar, xfdlist, betalist, wt=rep(1,N)) {
 #               it is converted to a list of length 1.
 #  WT       ... a vector of nonnegative weights for observations
 #
-#  Returns:
-#  FREGRESSLIST  ... A list containing seven members with names:
+#  Returns FREGRESSLIST  ... A list containing seven members with names:
 #    yfdPar      ... first  argument of FREGRESS
 #    xfdlist     ... second argument of FREGRESS
 #    betalist    ... third  argument of FREGRESS
@@ -41,32 +40,29 @@ fRegress <- function(yfdPar, xfdlist, betalist, wt=rep(1,N)) {
 #    wt          ... weights for observations
 #    df          ... degrees of freedom for fit
 
-#  Last modified 23 March 2007
+#  Last modified 21 October 2008 by Jim
 
-#  first check of XFDLIST
+#  check YFDPAR and compute sample size N
 
-if (inherits(xfdlist, "fd") || inherits(xfdlist, "numeric")) 
-    xfdlist <- list(xfdlist)
+if (inherits(yfdPar, "fd")) yfdPar <- fdPar(yfdPar)
 
-if (!inherits(xfdlist, "list")) stop(
-	"Argument XFDLIST is not a list object.")
+if (!(inherits(yfdPar, "fdPar") || inherits(yfdPar, "numeric"))) stop(
+  "First argument is not of class 'fd', 'fdPar' or 'numeric'.")
+
+if (inherits(yfdPar, "fdPar")) {
+    yfd   <- yfdPar$fd
+    ycoef <- yfd$coefs
+    N     <- dim(ycoef)[2]
+}
+if (inherits(yfdPar, "numeric")) {
+    N <- length(yfdPar)
+}
 
 #  get number of independent variables p
 
 p <- length(xfdlist)
 
-#  check contents of XFDCELL
-
-xerror <- FALSE
-for (j in 1:p) {
-	xfdj <- xfdlist[[j]]
-	if (!(inherits(xfdj, "fd") || is.numeric(xfdj))) {
-		print(paste("XFDLIST[[",j,"]] is neither a FD nor a NUMERIC object."))
-		xerror <- TRUE
-	}
-}
-
-#  first check of BETALIST
+#  check BETALIST
 
 if (inherits(betalist, "fd")) betalist <- list(betalist)
 
@@ -92,18 +88,85 @@ for (j in 1:p) {
 	}
 }
 
-if (xerror || berror) stop("")
+if (berror) stop("")
 
-if (inherits(yfdPar, "fdPar") || inherits(yfdPar, "fd")) {
+betafd1    <- betalist[[1]]$fd
+betabasis1 <- betafd1$basis
+rangeval   <- betabasis1$rangeval
+
+#  check XFDLIST
+
+if (inherits(xfdlist, "fd") || inherits(xfdlist, "numeric")) 
+    xfdlist <- list(xfdlist)
+
+if (!inherits(xfdlist, "list")) stop(
+	"Argument XFDLIST is not a list object.")
+
+#  check each xfdlist member.  If the object is a vector of length N,
+#  it is converted to a functional data object with a
+#  constant basis
+
+onebasis <- create.constant.basis(rangeval)
+onesfd   <- fd(1,onebasis)
+
+xerror <- FALSE
+for (j in 1:p) {
+    xfdj <- xfdlist[[j]]
+    if (inherits(xfdj, "fd")) {
+        xcoef <- xfdj$coefs
+        if (length(dim(xcoef)) > 2) stop(
+            paste("Covariate",j,"is not univariate."))
+        #  check size of coefficient array
+        Nj    <- dim(xcoef)[2]
+        if (Nj != N) {
+            print(
+               paste("Incorrect number of replications in XFDLIST",
+                     "for covariate",j))
+            xerror = TRUE
+        }
+    } 
+    if (inherits(xfdj, "numeric")) {
+        if (!is.matrix(xfdj)) xfdj = as.matrix(xfdj)
+	  Zdimj <- dim(xfdj)
+        if (Zdimj[1] != N) {
+            print(paste("Vector in XFDLIST[[",j,"]] has wrong length."))
+				    xerror = TRUE 
+		    } 
+        if (Zdimj[2] != 1) {
+            print(paste("Matrix in XFDLIST[[",j,"]] has more than one column."))
+				    xerror = TRUE 
+		    } 
+        xfdlist[[j]] <- fd(matrix(xfdj,1,N), onebasis)
+    } 
+    if (!(inherits(xfdlist[[j]], "fd") || 
+          inherits(xfdlist[[j]], "numeric"))) {
+      print(paste("XFDLIST[[",j,"]] is neither an FD object nor numeric."))
+      xerror = TRUE
+    }
+}
+    
+if (xerror) stop("")        
+
+#  check weights
+
+if (length(wt) != N) stop("Number of weights not equal to N.")
+if (any(wt < 0))     stop("Negative weights found.")
+if (length(wt) == 1 || var(wt) > 0) {
+    wtconstant <- F 
+} else {
+    wtconstant <- T
+}
+
+#  --------------------------------------------------------------------------
+#  branch depending on whether the dependent variable is functional or scalar 
+#  --------------------------------------------------------------------------
+
+if (inherits(yfdPar, "fdPar")) {
 	
     #  ----------------------------------------------------------------
-    #           YFDPAR is functional for a functional parameter
+    #           YFDPAR is a functional parameter object
     #  ----------------------------------------------------------------
 
-    # convert to a fdaPar object if required
-
-    if (inherits(yfdPar, "fd")) yfdPar <- fdPar(yfdPar)
-
     #  extract dependent variable information
 
     yfdobj    <- yfdPar$fd
@@ -118,50 +181,6 @@ if (inherits(yfdPar, "fdPar") || inherits(yfdPar, "fd")) {
 
     if (length(ycoefdim) > 2) stop("YFDOBJ from YFDPAR is not univariate.")
 
-    #  check each xfdlist member.  If the object is a vector of length N,
-    #  it is converted to a functional data object with a
-    #  constant basis
-
-    onebasis <- create.constant.basis(rangeval)
-    onesfd   <- fd(1,onebasis)
-
-    xerror <- FALSE
-    for (j in 1:p) {
-        xfdj <- xfdlist[[j]]
-        if (inherits(xfdj,"fd")) {
-            xcoef <- xfdj$coefs
-            if (length(dim(xcoef)) > 2) stop(
-					"Covariate is not univariate.")
-            rangevalx  <- xfdj$basis$rangeval
-            if (any(rangevalx != rangeval))  stop(
-					"Range for covariate does not match that of YFDOBJ")
-        } else {
-            xfdlist[[j]] <- fd(matrix(xfdj,1,N), onebasis)
-        }
-
-        #  check size of coefficient array
-        xfdj  <- xfdlist[[j]]
-        coefj <- xfdj$coefs
-        Nj <- dim(coefj)[2]
-        if (Nj != N) {
-            print(
-               paste("Incorrect number of replications in XFDLIST",
-                     "for covariate",j))
-            xerror = TRUE
-        }
-    }
-    if (xerror) stop("")
-
-    #  check weights
-
-    if (length(wt) != N) stop("Number of weights not equal to N.")
-    if (any(wt < 0))     stop("Negative weights found.")
-    if (length(wt) == 1 || var(wt) > 0) {
-       wtconstant <- FALSE 
-    } else {
-       wtconstant <- TRUE
-    }
-
     #  -----------------------------------------------------------
     #          set up the linear equations for the solution
     #  -----------------------------------------------------------
@@ -298,7 +317,10 @@ if (inherits(yfdPar, "fdPar") || inherits(yfdPar, "fd")) {
                  wt          = wt)
 
  }
- else if (inherits(yfdPar,"numeric")) {
+
+ #  -------------------------------------------------------------------
+
+ if (inherits(yfdPar,"numeric")) {
 
     #  ----------------------------------------------------------------
     #                   YFDPAR is scalar or multivariate
@@ -307,60 +329,37 @@ if (inherits(yfdPar, "fdPar") || inherits(yfdPar, "fd")) {
     ymat <- as.matrix(yfdPar)
     N    <- dim(ymat)[1]
 
-    #  check weights
-
-    if (length(wt) != N) stop("Number of weights not equal to N.")
-    if (any(wt < 0))     stop("Negative weights found.")
-
     Zmat  <- NULL
     Rmat  <- NULL
     pjvec <- rep(0,p)
     ncoef <- 0
     for (j in 1:p) {
         xfdj       <- xfdlist[[j]]
-        if (inherits(xfdj, "fd")) {
-            xcoef  <- xfdj$coefs
-            Nj 	 <- dim(xcoef)[2]
-            if (Nj != N) stop(
-				"Coefficient matrix has the wrong number of columns.")
-            xbasis     <- xfdj$basis
-            betafdParj <- betalist[[j]]
-            bbasis     <- betafdParj$fd$basis
-            bnbasis    <- bbasis$nbasis
-            pjvec[j]   <- bnbasis
-            Jpsithetaj <- inprod(xbasis,bbasis)
-            Zmat       <- cbind(Zmat,crossprod(xcoef,Jpsithetaj)) 
-            if (betafdParj$estimate) {
-                lambdaj    <- betafdParj$lambda
-                if (lambdaj > 0) {
-                    Lfdj   <- betafdParj$Lfd
-				       Rmatj <- lambdaj*eval.penalty(bbasis,Lfdj)
-                }
-                else Rmatj <- matrix(0,bnbasis,bnbasis)
-                if (ncoef > 0) {
-	                zeromat <- matrix(0,ncoef,bnbasis)
-                    Rmat  <- rbind(cbind(Rmat,       zeromat),
-                                   cbind(t(zeromat), Rmatj))
-                } else Rmat <- Rmatj
+        xcoef      <- xfdj$coefs
+        xbasis     <- xfdj$basis
+        betafdParj <- betalist[[j]]
+        bbasis     <- betafdParj$fd$basis
+        bnbasis    <- bbasis$nbasis
+        pjvec[j]   <- bnbasis
+        Jpsithetaj <- inprod(xbasis,bbasis)
+        Zmat       <- cbind(Zmat,crossprod(xcoef,Jpsithetaj)) 
+        if (betafdParj$estimate) {
+            lambdaj    <- betafdParj$lambda
+            if (lambdaj > 0) {
+                Lfdj  <- betafdParj$Lfd
+                Rmatj <- lambdaj*eval.penalty(bbasis,Lfdj)
+            } else {
+                Rmatj <- matrix(0,bnbasis,bnbasis)
+            }
+            if (ncoef > 0) {
+                zeromat <- matrix(0,ncoef,bnbasis)
+                Rmat    <- rbind(cbind(Rmat,       zeromat),
+                                 cbind(t(zeromat), Rmatj))
+            } else {
+                Rmat  <- Rmatj
                 ncoef <- ncoef + bnbasis
             }
         }
-        else if (inherits(xfdj, "double")) {
-            Zmatj  <- xfdj
-            Nj     <- dim(Zmatj)[1]
-            if (Nj != N) stop(
-				paste("Matrix in XFDLIST[[",j,"has the wrong number of rows."))
-            Zmat   <- cbind(Zmat,Zmatj)
-            ncoefj <- dim(Zmatj)[2]
-            Rmatj  <- matrix(0,ncoefj,ncoefj)
-            Rmat   <- rbind(cbind(Rmat, matrix(0,ncoef,ncoefj)),
-                           cbind(matrix(0,ncoefj,ncoef), Rmatj))
-            ncoef  <- ncoef + ncoefj
-          }
-        else stop(
-			paste("XFDLIST[[",j,
-			      "is neither a functional nor a multivariate object."))
-
     }
 
     #  -----------------------------------------------------------
@@ -412,7 +411,7 @@ if (inherits(yfdPar, "fdPar") || inherits(yfdPar, "fd")) {
             betaestlist[[j]] <- betaestfdParj
         }
         else{
-            betaestfdj       <- fd(t(betacoefj),onebasis)
+            betaestfdj       <- fd(as.matrix(t(betacoefj)),onebasis)
             betaestfdParj    <- betafdParj
             betaestfdParj$fd <- betaestfdj
             betaestlist[[j]] <- betaestfdParj
@@ -460,15 +459,9 @@ if (inherits(yfdPar, "fdPar") || inherits(yfdPar, "fd")) {
                  Cmatinv     = Cmatinv,
                  wt          = wt,
                  df          = df)
-}
- else {
-    	#  YFDOBJ is neither functional nor multivariate
-    	stop("YFDOBJ is neither functional nor multivariate.")
-	fRegressList <- list(0)
-}
+ }
 
-
-return(fRegressList)
+ return(fRegressList)
 
 }
 
